==> haskell-optics-extra-0.4.2.1-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optics-extra
version:              0.4.2.1
visibility:           public
id:                   optics-extra-0.4.2.1-161yi2GIFz25C6F0o8EZSS
key:                  optics-extra-0.4.2.1-161yi2GIFz25C6F0o8EZSS
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Extra utilities and instances for optics-core
description:
    This package provides extra definitions and instances that extend the
    @<https://hackage.haskell.org/package/optics-core optics-core>@ package,
    without incurring too many dependencies.  See the
    @<https://hackage.haskell.org/package/optics optics>@ package for more
    documentation.

category:             Data, Optics, Lenses
abi:                  bf8f8db79806a558b7814ec39ba88d9b
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Optics Data.ByteString.Optics
    Data.ByteString.Strict.Optics Data.HashMap.Optics
    Data.HashSet.Optics Data.Text.Lazy.Optics Data.Text.Optics
    Data.Text.Strict.Optics Data.Vector.Generic.Optics
    Data.Vector.Optics Optics.At Optics.Cons Optics.Each Optics.Empty
    Optics.Extra Optics.Extra.Internal.ByteString
    Optics.Extra.Internal.Vector Optics.Extra.Internal.Zoom
    Optics.Indexed Optics.Passthrough Optics.State
    Optics.State.Operators Optics.View Optics.Zoom

import-dirs:          /usr/lib/ghc-9.0.2/site-local/optics-extra-0.4.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/optics-extra-0.4.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-extra
hs-libraries:         HSoptics-extra-0.4.2.1-161yi2GIFz25C6F0o8EZSS
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    hashable-1.4.1.0-LUNCtsUMK7L3ZB2KEKWF7F
    indexed-profunctors-0.1.1-5fGRVjLEHI0IPX9k0oVbdA
    indexed-traversable-instances-0.1.1.1-FBkYLpT4LalDTz44MwmQjh
    mtl-2.2.2 optics-core-0.4.1-D9hVTcZ3gl3BaQvciiwo0B text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-1t66PwyRMuzEgWVME6Xx4r
    vector-0.13.0.0-80dNWv5W93FGfZf7Ao5mAf

haddock-interfaces:
    /usr/share/doc/haskell-optics-extra/html/optics-extra.haddock

haddock-html:         /usr/share/doc/haskell-optics-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optics-extra-0.4.2.1-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optics-extra
version:              0.4.2.1
visibility:           public
id:                   optics-extra-0.4.2.1-KviY8RvgVnL8u3dQi7aZJz
key:                  optics-extra-0.4.2.1-KviY8RvgVnL8u3dQi7aZJz
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Extra utilities and instances for optics-core
description:
    This package provides extra definitions and instances that extend the
    @<https://hackage.haskell.org/package/optics-core optics-core>@ package,
    without incurring too many dependencies.  See the
    @<https://hackage.haskell.org/package/optics optics>@ package for more
    documentation.

category:             Data, Optics, Lenses
abi:                  6ce77fa635afc4a84e112e1f571cf189
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Optics Data.ByteString.Optics
    Data.ByteString.Strict.Optics Data.HashMap.Optics
    Data.HashSet.Optics Data.Text.Lazy.Optics Data.Text.Optics
    Data.Text.Strict.Optics Data.Vector.Generic.Optics
    Data.Vector.Optics Optics.At Optics.Cons Optics.Each Optics.Empty
    Optics.Extra Optics.Extra.Internal.ByteString
    Optics.Extra.Internal.Vector Optics.Extra.Internal.Zoom
    Optics.Indexed Optics.Passthrough Optics.State
    Optics.State.Operators Optics.View Optics.Zoom

import-dirs:          /usr/lib/ghc-9.0.2/site-local/optics-extra-0.4.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/optics-extra-0.4.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-extra
hs-libraries:         HSoptics-extra-0.4.2.1-KviY8RvgVnL8u3dQi7aZJz
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    hashable-1.4.2.0-8JSq7I7AhyyZ2Q90BxZWW
    indexed-profunctors-0.1.1.1-FtNuykj07dlNVtQ9HC5Fh
    indexed-traversable-instances-0.1.1.2-ITg9ZgLh5kL5mJNTLzSwI3
    mtl-2.2.2 optics-core-0.4.1.1-DgtHUlsNuEMK8847xWLVDG text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-Km0aDxhChoIJJSbiufyazz
    vector-0.13.0.0-9fyHsAonVFcGYv9jtLmfSh

haddock-interfaces:
    /usr/share/doc/haskell-optics-extra/html/optics-extra.haddock

haddock-html:         /usr/share/doc/haskell-optics-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
